<?php


/*
 * Register custom post type for special use
 */
if(!function_exists('a13_cpt_register')){
    function a13_cpt_register(){

        $labels = array(
            'name' => _x( 'My Albums', 'post type general name', TPL_SLUG ),
            'singular_name' => _x( 'Album', 'post type singular name', TPL_SLUG ),
            'add_new' => _x( 'Add New', 'album item', TPL_SLUG ),
            'add_new_item' => __be( 'Add New Album' ),
            'edit_item' => __be( 'Edit Album' ),
            'new_item' => __be( 'New Album' ),
            'view_item' => __be( 'View Album' ),
            'search_items' => __be( 'Search Albums' ),
            'not_found' =>  __be( 'Nothing found' ),
            'not_found_in_trash' => __be( 'Nothing found in Trash' ),
            'parent_item_colon' => ''
        );

        $args = array(
            'labels' => $labels,
            'public' => true,
            'query_var' => true,
            'menu_position' => 5,
            'rewrite' =>  array('slug' => CUSTOM_POST_TYPE_SLUG),
            'supports' => array( 'title','thumbnail' ),
        );

        register_post_type( CUSTOM_POST_TYPE , $args );

        $genre_labels = array(
            'name' => __be( 'Album Genres' ),
            'singular_name' => __be( 'Genre' ),
            'search_items' =>  __be( 'Search Genres' ),
            'popular_items' =>  __be( 'Popular Genres' ),
            'all_items' => __be( 'All Genres' ),
            'parent_item' => __be( 'Parent Genre' ),
            'parent_item_colon' => __be( 'Parent Genre:' ),
            'edit_item' => __be( 'Edit Genre' ),
            'update_item' => __be( 'Update Genre' ),
            'add_new_item' => __be( 'Add New Genre' ),
            'new_item_name' => __be( 'New Genre Name' ),
            'menu_name' => __be( 'Genre' ),
        );

        register_taxonomy("genre", array(CUSTOM_POST_TYPE),
            array(
                "hierarchical" => false,
                "label" => __be('Album Categories'),
                "labels" => $genre_labels,
                "rewrite" => true,
                'show_admin_column' => true
            )
        );

        //flush if settings has changed
        if ( defined( 'APOLLO13_SETTINGS_CHANGED' ) && APOLLO13_SETTINGS_CHANGED ) {
            flush_rewrite_rules();
        }

    }
}



/*
 * Making cover album images in Albums list
 */
if(!function_exists('a13_make_album_image')){
    function a13_make_album_image( $album_id, $thumb_size, $hidden = false ){
        if(empty($album_id)){
            $album_id = get_the_ID();
        }
        if ( has_post_thumbnail($album_id) ) {
            $src = wp_get_attachment_image_src( get_post_thumbnail_id ( $album_id ), $thumb_size );
            $src = $src[0];
        }
        else{
            $src = TPL_GFX . '/photo.jpg';
        }

        $style = '';
        if($hidden){
            $style = ' style="visibility: hidden;"';
        }

        return '<img src="'.$src.'" alt=""'.$style.' />';
    }
}


/*
 * For printing categories(taxonomies) of custom type post
 */
if(!function_exists('a13_cpt_posted_in')){
    function a13_cpt_posted_in( $term_list, $separator = '<span>/</span>' ) {
        $count_terms = count( $term_list );
        $iter = 1;
        if( $count_terms ){
            foreach($term_list as $term) {
                echo '<a href="' . get_term_link($term) . '">' . $term->name . '</a>';
                if( $count_terms != $iter ){
                    echo $separator;
                }
                $iter++;
            }
        }
    }
}



/*
 * Collection of photos
 */
if(!function_exists('a13_make_collection')){
    function a13_make_collection($id = 0, $noJSON = false){
        $is_album = defined('ALBUM_PAGE')? true : false;
        $canHaveMeta = (is_singular() || is_home() || is_front_page());
        $ID = 0;

        if($is_album){
                $ID = get_the_ID();
        }
        elseif($id !== 0){
            $ID = $id;
        }
        elseif(is_404()){
            return '[]';
        }
        //check if blog page has background album
        //check if this page has background album
        else{
            $pID = 0;
            if($canHaveMeta){
                $pID = is_home()? get_option('page_for_posts') : get_the_ID();
            }
            $i_or_a = $canHaveMeta ? get_post_meta($pID, '_image_or_album', true) : false;

            //if single image as background
            if($i_or_a == 'bg_image_1'){
                $bg_image = get_post_meta($pID, '_bg_image_1', true);
                if(!empty($bg_image)){
                    define('ADD_HIDE_SWITCH', 1);

                    return '[' . str_replace( '\/','/', json_encode(
                        array(
                            'singlebg'      => 1,
                            'image'         => $bg_image,
                            'bg_color'      => get_post_meta($pID, '_bg_image_color_1', true),
                            'fit'           => get_post_meta($pID, '_bg_image_fit_1', true),
                        )
                    )) . ']';
                }
            }
            //album as background
            elseif($i_or_a == 'bg_album_1'){
                $ID = trim( get_post_meta($pID, '_bg_album_1', true) );
            }
        }

        //'none' or no album selected
        if($ID === 0 || !$ID ){
            return '[]';
        }
        $slides = array();
        $media_count = get_post_meta($ID, '_image_count', true);

        //default album settings
        $a_bg_color           = trim( get_post_meta($ID, '_bg_color', true) );
        $a_desc               = trim( get_post_meta($ID, '_description', true) );
        $pattern              = trim( get_post_meta($ID, '_pattern', true) );
        $pattern_opacity      = trim( get_post_meta($ID, '_pattern_opacity', true) );
        $thumb_size           = 'album-thumb';
        //if bricks theme use different size thumbs
        if($is_album && trim( get_post_meta($ID, '_theme', true) ) == 'bricks'){
            $thumb_size = 'album-bricks';
        }
        else{
            //this is full screen album or background album
            if(!$noJSON)//not request for a slider
                define('ADD_HIDE_SWITCH', 1);
        }



        //!!!!!!!
        //check if we saved items new way, free from Album items limit bug
        $old_way_data = false;
        $images_videos_array = get_post_meta($ID, '_images_n_videos' , true);
        if($images_videos_array !== '[]' && strlen($images_videos_array) !== 0){
            $images_videos_array = json_decode($images_videos_array, true);
            $media_count = count($images_videos_array);
        }
        else{
            $old_way_data = true;
//            var_dump('old way!');

            /* !!!!!!!!!!!!!!!!!!!!!!!
            Below code is from 2nd old way of saving data.
            It was unsuccessful attempt to fix Album items limit bug. No we have to support it */
            //-----------------------------
            //try to get new way saved data
            $new_way = false;
            $current_element = '';
            $images_videos_array = get_post_meta($ID, '_collection_of_images_and_videos' , true);

            if(!empty($images_videos_array)){
                $images_videos_array = unserialize($images_videos_array);
            }

            //data was saved new way
            if(!empty($images_videos_array)){
                $new_way = true;
                $current_element = current($images_videos_array);
            }
            //-----------------------------
        }

        if( $media_count ){
            if($old_way_data){

                for( $i = 1; $i <= $media_count; $i++ ){
                    //image or video?
                        $switch = $new_way? $current_element['image_or_video'] : get_post_meta($ID, '_image_or_video_' . $i, true);
                    if( $switch ){
                        //make name for hidden meta field
                        $media = $new_way? $current_element[substr($switch, 0, strrpos($switch, '_'))] : get_post_meta($ID, '_' . $switch, true);
                        if( $media ){
                            //local item settings VS album settings
                            //image | video
                            $type               = substr( $switch, 5, 5 );
                            if($type == 'image'){
                                $caption            = trim( $new_way? $current_element['post_image_name'] : get_post_meta($ID, '_post_image_name_' . $i, true) );

                                $desc               = trim( $new_way? $current_element['post_image_desc'] : get_post_meta($ID, '_post_image_desc_' . $i, true) );
                                $desc               = (empty($desc))? $a_desc : $desc;

                                $bg_color           = trim( $new_way? $current_element['bg_color'] : get_post_meta($ID, '_bg_color_' . $i, true) );
                                $bg_color           = (empty($bg_color))? $a_bg_color : $bg_color;

                                $thumb              = $media;
                                $attachment_id      = trim( $new_way? $current_element['post_image_id'] : get_post_meta($ID, '_post_image_id_' . $i, true) );
                                $link               = $media;
                                //can get normal thumb ?
                                if(!empty($attachment_id)){
                                    $thumb = wp_get_attachment_image_src($attachment_id, $thumb_size);
                                    if(!$thumb){
                                        $thumb = $media;
                                    }
                                    else{
                                        $thumb = $thumb[0];
                                        $link  = get_attachment_link($attachment_id);
                                    }
                                }

                                //fill array with values
                                $slides[] = array(
                                    'type'              => $type,
                                    'image'             => $media,
                                    'thumb'             => $thumb,
                                    'title'             => stripcslashes($caption),
                                    'desc'              => do_shortcode(stripcslashes($desc)),
                                    'bg_color'          => $bg_color,
                                    'pattern'           => $pattern,
                                    'pattern_opacity'   => $pattern_opacity,
                                    'link'              => $link,
                                    'id'                => $i
                                );
                            }

                            elseif($type == 'video'){
                                $v_arr = a13_detect_movie($media);
                                $thumb = a13_get_movie_thumb_src($v_arr, trim( $new_way? $current_element['video_thumb'] : get_post_meta($ID, '_video_thumb_' . $i, true) ) );
                                $movie_link  = a13_get_movie_link($v_arr, array('width' => 500, 'height' => 500));
                                $autoplay = trim( $new_way? $current_element['video_autoplay'] : get_post_meta($ID, '_video_autoplay_' . $i, true) );

                                //fill array with values
                                $slides[] = array(
                                    'type'              => $type,
                                    'image'             => $movie_link,
                                    'thumb'             => $thumb,
                                    'autoplay'          => $autoplay,
                                    'movie_type'        => $v_arr['type'],
                                    'link'              => $media
                                );
                            }
                        }
                    }

                    //get next element
                    if($new_way){
                        $current_element = next($images_videos_array);
                    }
                }
            }
            else{
                for( $i = 0; $i < $media_count; $i++ ){
                    $current_element = $images_videos_array[$i];
                    //image or video?
                    $type = $current_element['item_type'];

                    //image | video
                    if( $type ){

                        $caption            = trim( $current_element['item_title'] );
                        $desc               = trim( $current_element['item_desc'] );
                        $desc               = (empty($desc))? $a_desc : $desc;
                        //local item settings VS gallery settings
                        $desc               = (empty($desc))? nl2br($a_desc) : nl2br($desc);

                        if($type === 'image'){
                            $media              = $current_element['item_image'];
                            //no image so we skip this item
                            if(!strlen($media)){
                                continue;
                            }

                            $attachment_id      = trim( $current_element['attachment_id'] );

                            $link               = trim( $current_element['item_link'] );
                            $bg_color           = trim( $current_element['bg_color'] );
                            $bg_color           = (empty($bg_color))? $a_bg_color : $bg_color;
                            $thumb              = $media;

                            //can get normal thumb ?
                            if(!empty($attachment_id)){
                                $thumb = wp_get_attachment_image_src($attachment_id, $thumb_size);
                                if(!$thumb){
                                    $thumb = $media;
                                }
                                else{
                                    $thumb = $thumb[0];
                                    $link  = get_attachment_link($attachment_id);
                                }
                            }


                            //fill array with values
                            $slides[] = array(
                                'type'              => $type,
                                'image'             => $media,
                                'thumb'             => $thumb,
                                'title'             => $caption,
                                'desc'              => $desc,
                                'bg_color'          => $bg_color,
                                'pattern'           => $pattern,
                                'pattern_opacity'   => $pattern_opacity,
                                'link'              => $link,
                                'id'                => $i
                            );
                        }

                        elseif($type === 'video'){
                            $media          = $current_element['item_video'];
                            if(!strlen($media)){
                                continue;
                            }

                            $v_arr          = a13_detect_movie($media);
                            $thumb          = a13_get_movie_thumb_src($v_arr, trim( $current_element['item_video_thumb'] ) );
                            $movie_link     = a13_get_movie_link($v_arr, array('width' => 500, 'height' => 500, 'poster' => $thumb));
                            $autoplay       = trim( $current_element['item_video_autoplay'] );

                            //fill array with values
                            $slides[] = array(
                                'type'              => $type,
                                'image'             => $movie_link,
                                'thumb'             => $thumb,
                                'title'             => $caption,
                                'desc'              => $desc,
                                'autoplay'          => $autoplay,
                                'movie_type'        => $v_arr['type'],
                                'link'              => $media
                            );
                        }
                    }
                }
            }

            if( sizeof($slides) ){
                //used for slider
                if($noJSON)
                    return $slides;

                //add script for viewing album
                wp_enqueue_script('album-view');
                return str_replace( '\/','/', json_encode($slides));
            }
            else{
                if($noJSON)
                    return array();
                else
                    return '[]';
            }
        }
        else{
            return '[]';
        }
    }
}

if(!function_exists('a13_make_collection_HTML')){
    function a13_make_collection_HTML(){
        $slides = a13_make_collection(get_the_ID(), true);
        $html = '';
        if(sizeof($slides)){
            $html = '<div class="seo-album">';

            foreach($slides as $slide ){
                if($slide['type'] == 'image'){
                    $html .= '
                    <div class="brick">
                        <a href="'.$slide['image'].'"><img src="'.$slide['thumb'].'" alt="" /></a>
                        <em id="brick-title-'.$slide['id'].'">'.$slide['title'].'</em>
                        <div>'.$slide['desc'].'</div>
                    </div>';
                }
                elseif($slide['type'] == 'video'){
                    $html .= '
                    <div class="brick">
                        <a href="'.$slide['link'].'"><img src="'.$slide['thumb'].'" alt="" /></a>
                    </div>';
                }
            }

            $html .= '</div>';
        }

        return $html;
    }
}

add_action( 'init', 'a13_cpt_register' );


/******************************/
/************** AJAX **********/
/******************************/

function ajax_get_album_names() {
    global $wp_query;

    $args = array(
        'posts_per_page'      => -1,
        'offset'              => -1,
        'post_type'           => CUSTOM_POST_TYPE,
        'post_status'         => 'publish',
        'ignore_sticky_posts' => true,
        'meta_key' => '_background_only',
        'meta_value' => '0',
    );

    //make query for albums
    $wp_query = new WP_Query( $args );

    $albums = array();

    if ($wp_query->have_posts()) :
        while ( have_posts() ) :
            the_post();
            //if password protected album, don't list it
            if(post_password_required())
                continue;

            $albums[] = array(
                'id'   => get_the_ID(),
                'name' => get_the_title(),
                'link' => get_permalink()
            );
        endwhile;
    endif;

    echo  json_encode(array('albums' => $albums));

    die(); // this is required to return a proper result
}

function ajax_get_this_album() {
    global $apollo13;
    $album_id = $_POST['id'];
    echo '{"items":' . a13_make_collection($album_id) . ','
         .'"fit":"'.$apollo13->get_meta('_fit_image', $album_id).'",'
         .'"transition":"'.$apollo13->get_meta('_transition', $album_id).'",'
         .'"random":'.$album_random = $apollo13->get_meta('_random', $album_id).'}';

//    echo  json_encode(array('albums' => $albums));

    die(); // this is required to return a proper result
}


if(is_admin()){
    add_action('wp_ajax_get_album_names', 'ajax_get_album_names');
    add_action('wp_ajax_nopriv_get_album_names', 'ajax_get_album_names');

    add_action('wp_ajax_get_this_album', 'ajax_get_this_album');
    add_action('wp_ajax_nopriv_get_this_album', 'ajax_get_this_album');
}
