<?php

/*
 * Frontend theme scripts
 */
if(!function_exists('a13_theme_scripts')){
    function a13_theme_scripts(){
        global $apollo13;


        if(is_admin() || 'wp-login.php' == basename($_SERVER['PHP_SELF'])){
            return;
        }

        /* We add some JavaScript to pages with the comment form
          * to support sites with threaded comments (when in use).
          */
        if ( is_singular() && get_option( 'thread_comments' ) ){
            wp_enqueue_script( 'comment-reply' );
        }


        $script_depends = array( 'apollo13-plugins' );

        /* I REALLY DON"T LIKE IT, but theme control don't allow us to use it
         * I understand were they coming from, still don't like it(http://ivor.bz/PuK5)
         * ******************************
         * //register jQuery from CDN
         * //WHY NOT IN FOOTER? Cause twitter plugin inserts inline JS that uses jQuery
         * //wp_deregister_script( 'jquery' );
         * //wp_register_script( 'jquery', 'http://code.jquery.com/jquery-1.7.2.min.js');
        */

        //script for slides in album
        wp_register_script('album-view', TPL_JS . '/album-view-full.js',array('jquery'), THEME_VER, true);

        //plugins used in theme (cheat sheet)
        wp_register_script('apollo13-plugins', TPL_JS . '/plugins.js',
            array('jquery'), //depends
            THEME_VER, //version number
            true //in footer
        );



        //twitter widget
        wp_register_script( 'twitter-widget', TPL_JS . '/twitter-widget.js', array('jquery'), THEME_VER);

        //masonry
        wp_register_script( 'masonry', TPL_JS . '/jquery.masonry-with-resize-plugin.min.js', array('jquery'), '2.5', true);

        //for audio posts and bg music
        wp_register_script('apollo13-audio', TPL_JS . '/audio/jquery.jplayer.min.js',array('jquery'), '2.2.0', true );

        //for slider
        wp_register_script('flex-slider', TPL_JS . '/jquery.flexslider-min.js',array('jquery'), '2.1.0', true );

        $is_album = defined('ALBUM_PAGE')? true : false;
        $is_albums_list = defined('ALBUMS_LIST_PAGE')? true : false;

        //add masonry if needed
        if(
            (is_home() && $apollo13->get_option('blog', 'blog_layout_style') == 'masonry')
        ||  ((is_archive() || is_search()) && $apollo13->get_option('blog', 'archive_layout_style') == 'masonry')
        ||  ($is_album && $apollo13->get_meta('_theme') == 'bricks')
        ||  ($is_albums_list && $apollo13->get_option('albums', 'albums_list_style') == 'bricks')
        ){
            array_push($script_depends, 'masonry');
        }

        //options passed to JS
        $apollo_params = a13_js_parameters();
        //hand written scripts for theme
        wp_enqueue_script('apollo13-scripts', TPL_JS . '/script.js', $script_depends, THEME_VER, true );
        //transfer options
        wp_localize_script( 'apollo13-plugins', 'ApolloParams', $apollo_params );

        //remove admin bar margin in html element
        remove_action('wp_head', '_admin_bar_bump_cb');
    }
}

if(!function_exists('a13_js_parameters')){
    function a13_js_parameters(){
        global $apollo13;

        /* Album compare local and global setting*/
        $is_album = defined('ALBUM_PAGE')? true : false;
        $canHaveMeta = (is_singular() || is_home() || is_front_page());
        $ID = 0;
        if(!is_404() && $canHaveMeta){
            if(is_home() && get_option('page_for_posts') !== '0'){
                $ID = trim( get_post_meta(get_option('page_for_posts'), '_bg_album_1', true) );
            }
            else{
                $ID = ($is_album)? get_the_ID() : trim( get_post_meta(get_the_ID(), '_bg_album_1', true) );
            }
        }


        $album_autoplay = $canHaveMeta ? $apollo13->get_meta( '_album_autoplay', $ID ) : '';

        $album_transition = $canHaveMeta ? $apollo13->get_meta( '_transition', $ID ) : '';

        $album_thumb_links = $canHaveMeta ? $apollo13->get_meta('_thumb_links', $ID) : '';

        $album_thumbs_on_start = $canHaveMeta ? $apollo13->get_meta('_thumbs_on_start', $ID) : '';

        $album_random = $canHaveMeta ? $apollo13->get_meta('_random', $ID) : '';
        $album_icon_desc = $canHaveMeta ? $apollo13->get_meta('_album_icon_desc', $ID) : '';
        $album_icon_link = $canHaveMeta ? $apollo13->get_meta('_album_icon_link', $ID) : '';
        $album_icon_share = $canHaveMeta ? $apollo13->get_meta('_album_icon_share', $ID) : '';

        $album_theme = 'full';

        $album_fit_image = '';

        $images = '[]';//empty by default

        if($ID === 0 || !$ID ){}
        else{
            if((is_single() || is_page()) && (get_post_meta(get_the_ID(), '_image_or_album', true) == 'bg_album_1')){
                $album_fit_image = $apollo13->get_meta('_fit_image', $ID);
            }
            elseif($is_album){
                $album_fit_image = $apollo13->get_meta('_fit_image', $ID);
                $album_theme = $apollo13->get_meta('_theme', $ID);
            }
        }
        /* /Album compare local and global setting*/

        //for sending album images to JS and single background image
        $images = a13_make_collection();

        /* Autoplay background music */
        $autoplay = $apollo13->get_option( 'music', 'music_autoplay' );
        //if player is turned on
        if($apollo13->get_option( 'music', 'music_player' ) == 'on'){
            if(is_front_page()){
                $autoplay = $apollo13->get_option( 'settings', 'fp_music_autoplay' );
            }
            elseif(is_home()){
                $autoplay = $apollo13->get_meta('_music_autoplay', get_option('page_for_posts'));
            }
            else{
                $autoplay = $canHaveMeta ? $apollo13->get_meta('_music_autoplay') : '';
            }
        }
        /* /Autoplay background music */

        //options transferred to js files
        return array(
            /* SINGLE OPTIONS */
            'ajaxurl' => admin_url('admin-ajax.php'),
            'social_number_of_visible' => $apollo13->get_option( 'social', 'social_number_of_visible' ),
            'social_icon_width' => SOCIAL_ICON_WIDTH,
            'images_dir'        => TPL_GFX,
            'js_dir'            => TPL_JS,
            'placeholder_image' => '/photo.jpg',
            'validation_class'  => VALIDATION_CLASS,
            'touch_classic_menu'=> ($apollo13->get_option( 'appearance', 'touch_force_classic_menu' ) == 'on')? 1 : 0,
            'load_more'         => __fe('Load more'),

            /* BLOG */
            'brick_width'               => $apollo13->get_option( 'blog', 'brick_width' ),
            'brick_margin'              => $apollo13->get_option( 'blog', 'brick_margin' ),
            'masonry_full_width'        => ($apollo13->get_option( 'blog', 'blog_full_width' ) == 'on')? 1 : 0,

            /* ALBUMS LIST */
            'albums_animationTime'      => $apollo13->get_option( 'albums', 'albums_animation_time' ),
            'albums_loadingFadeTime'    => $apollo13->get_option( 'albums', 'albums_fade_time' ),
            'albums_borderWidth'        => $apollo13->get_option( 'albums', 'albums_border_size' ),
            'albums_activeZoom'         => $apollo13->get_option( 'albums', 'albums_zoom_size' ),
            'albums_spaceOutside'       => $apollo13->get_option( 'albums', 'albums_margin_size' ),
            'albums_maxHeight'          => $apollo13->get_option( 'albums', 'albums_max_height' ),
            'albums_startItem'          => $apollo13->get_option( 'albums', 'start_album' ),
            'albums_brick_width'        => $apollo13->get_option( 'albums', 'albums_brick_width' ),
            'albums_brick_height'       => $apollo13->get_option( 'albums', 'albums_brick_height' ),
            'albums_brick_margin'       => $apollo13->get_option( 'albums', 'albums_brick_margin' ),

            /* SINGLE ALBUM OPTIONS */
            //images for album
            'l10n_print_after'          => 'ApolloParams.album_images=' . $images, //hidden field that wordpress passes without adding slashes :-)
            'album_autoplay'            => $album_autoplay,
            'album_slide_interval'      => $apollo13->get_option( 'albums', 'album_slide_interval' ),
            'album_transition'          => $album_transition,
            'album_slide_transition'    => $apollo13->get_option( 'albums', 'album_slide_transition' ),
            'album_thumb_links'         => $album_thumb_links,
            'album_thumbs_on_start'     => $album_thumbs_on_start,
            'album_random'              => $album_random,
            'album_fit_image'           => $album_fit_image,
            'album_image_quality'       => $apollo13->get_option( 'albums', 'album_image_quality' ),
            'album_other_albums'        => $apollo13->get_option( 'albums', 'album_other_albums' ),
            'album_theme'               => $album_theme,
            'album_icon_desc'           => $album_icon_desc,
            'album_icon_link'           => $album_icon_link,
            'album_icon_share'          => $album_icon_share,
            'current_album_id'          => ($is_album)? get_the_ID() : 0,
            'album_brick_width'         => $apollo13->get_option( 'albums', 'album_brick_width' ),
            'album_brick_height'        => $apollo13->get_option( 'albums', 'album_brick_height' ),
            'album_brick_margin'        => $apollo13->get_option( 'albums', 'album_brick_margin' ),


            /* HEADER MUSIC */
            'header_music_mp3'      => $apollo13->get_option( 'music', 'music_mp3' ),
            'header_music_ogg'      => $apollo13->get_option( 'music', 'music_ogg' ),
            'header_music_player'   => $apollo13->get_option( 'music', 'music_player' ),
            'header_music_autoplay' => $autoplay,
        );
    }
}

/*
 * Adds CSS files to theme
 */
if(!function_exists('a13_theme_styles')){
    function a13_theme_styles(){
        if(is_admin() || 'wp-login.php' == basename($_SERVER['PHP_SELF'])){
            return;
        }

        global $apollo13;

        $user_css_depends = array('main-style');

        wp_register_style( 'main-style', TPL_URI . '/style.css', false, THEME_VER);

        //for audio post format support
        wp_register_style('audio-css', TPL_CSS . '/pink.flag/jplayer.pink.flag.css', array('main-style'), THEME_VER);

        //for slider
        wp_register_style('flex-slider', TPL_CSS . '/flexslider.css', array('main-style'), THEME_VER);

        //color scheme
        if($apollo13->get_option( 'appearance', 'color_scheme' ) == 'black'){
            wp_register_style('black-scheme', TPL_CSS . '/black.css', array('main-style'), THEME_VER);
            array_push($user_css_depends, 'black-scheme');
        }

        wp_register_style('user-css', $apollo13->user_css_name(true), $user_css_depends, THEME_VER);
        wp_enqueue_style('user-css');
    }
}

/*
 * if there is something that can't be added in theme_styles or theme_scripts, add it here
 */
if(!function_exists('a13_theme_head')){
    function  a13_theme_head(){
        if(is_admin() || 'wp-login.php' == basename($_SERVER['PHP_SELF'])){
            return;
        }
        //add here your scripts and other things

        global $apollo13;

        //WEB FONTS LOADING
        $fonts = array( 'families' => array());
        //check if classic or google font is selected
        //colon in name = google font
        $temp = $apollo13->get_option('fonts', 'normal_fonts');
        (strpos($temp, ':') !== false)? array_push($fonts['families'], $temp) : false;
        $temp = $apollo13->get_option('fonts', 'titles_fonts');
        (strpos($temp, ':') !== false)? array_push($fonts['families'], $temp) : false;
        $temp = $apollo13->get_option('fonts', 'nav_menu_fonts');
        (strpos($temp, ':') !== false)? array_push($fonts['families'], $temp) : false;

        if(sizeof($fonts['families'])):
            $fonts = json_encode($fonts);
    ?>

    <script type="text/javascript">
        WebFontConfig = {
            google: <?php echo $fonts; ?>,
            active: function() {
                //tell listeners that fonts are loaded
                jQuery(document.body).trigger('webfontsloaded');
            }
        };
        (function() {
            var wf = document.createElement('script');
            wf.src = ('https:' == document.location.protocol ? 'https' : 'http') +
                    '://ajax.googleapis.com/ajax/libs/webfont/1.0.31/webfont.js';
            wf.type = 'text/javascript';
            wf.async = 'true';
            var s = document.getElementsByTagName('script')[0];
            s.parentNode.insertBefore(wf, s);
        })();
    </script>

    <?php
        endif;
    }
}

add_action( 'wp_print_scripts', 'a13_theme_scripts' );
add_action( 'wp_print_styles', 'a13_theme_styles' );
add_action( 'wp_head', 'a13_theme_head' );