<?php
/* Generates user css based on settings in admin panel */

function apollo13_make_css_rule($property, $value, $format = false){
    if ( $value !== '' &&  $value !== 'default' ){
        //make fallback for rgba colors by providing rgb color
        if(strpos($property,'color') !== false && strpos($value,'rgba') !== false){
            //break rgba to numbers
            $chunks = break_rgba($value);
            $fallback_color = "rgb($chunks[1], $chunks[2], $chunks[3])";

            return
                $property . ': ' . $fallback_color . "; " .
                $property . ': ' . $value . ';';
        }

        //format for some properties
        if( $format !== false ){
            return $property . ': ' . sprintf($format, $value) . ';';
        }

        return $property . ': ' . $value . ";";
    }
    else{
        return '';
    }
}

/* only for background color
 * it gives RGBA possibility to IE
*/
function apollo13_ie_color($property, $value){
    if(strpos($value,'rgba') !== false){
        //break rgba to numbers
        $chunks = break_rgba($value);

        $ie_color = rgba2hex($chunks[1], $chunks[2], $chunks[3], $chunks[4]);

        $css =
            'background-color: transparent; ' .
                'filter:progid:DXImageTransform.Microsoft.gradient(startColorStr='.$ie_color.',endColorStr='.$ie_color.'); ' .
                'zoom: 1;';

        return $css;
    }
    else{
        return apollo13_make_css_rule($property, $value);
    }
}

function rgba2hex( $r, $g, $b, $a ){
    return sprintf( '#%02s%02s%02s%02s', dechex( 255 * $a ), dechex( $r ), dechex( $g ), dechex( $b ) );
}

function break_rgba( $rgba ){
    $chunks = array();
    preg_match("/\(\s*(\d+),\s*(\d+),\s*(\d+),\s*(\d+\.?\d*)\s*\)/", $rgba, $chunks);
    return $chunks;
}


/*
 * body part
 */
$body_bg_color              = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'body_bg_color' ]);
$body_image                 = apollo13_make_css_rule( 'background-image', $this->theme_options[ 'appearance' ][ 'body_image' ], 'url(%s)');
$body_repeat                = apollo13_make_css_rule( 'background-repeat', $this->theme_options[ 'appearance' ][ 'body_repeat' ]);
$headings_color             = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'headings_color' ]);
$headings_color_hover       = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'headings_color_hover' ]);
$links_color                = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'links_color' ]);
$links_color_hover          = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'links_color_hover' ]);
$buttons_bg_color           = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'links_color' ]);
$buttons_bg_color_ie        = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'appearance' ][ 'links_color' ]);
$buttons_bg_color_hover     = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'links_color_hover' ]);
$buttons_bg_color_hover_ie  = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'appearance' ][ 'links_color_hover' ]);

$alias = $this->theme_options[ 'appearance' ][ 'body_position_x' ];
$alias2 = $this->theme_options[ 'appearance' ][ 'body_position_y' ];
$body_position = '';
if ( ! empty( $alias ) && ! empty( $alias2 ) && $alias != 'default' && $alias2 != 'default' ){
    $body_position = 'background-position: ' . $alias . ' ' . $alias2 . ';';
}


/*
 *  header part
 */
$addons_bg_color        = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'header_addons_bg_color' ]);
$addons_bg_color_ie     = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'appearance' ][ 'header_addons_bg_color' ]);
$addons_arrow_color     = apollo13_make_css_rule( 'border-top-color', $this->theme_options[ 'appearance' ][ 'header_addons_bg_color' ]);
$addons_font_size       = apollo13_make_css_rule( 'font-size', $this->theme_options[ 'appearance' ][ 'header_addons_font_size' ]);
$header_bg_color        = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'header_bg_color' ]);
$header_bg_color_ie     = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'appearance' ][ 'header_bg_color' ]);
$logo_image             = apollo13_make_css_rule( 'background-image', $this->theme_options[ 'appearance' ][ 'logo_image' ], 'url(%s)');
$menu_bg_color          = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'menu_lvl2_bg_color' ]);
$menu_bg_color_ie       = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'appearance' ][ 'menu_lvl2_bg_color' ]);
$menu_lvl1_sep_color    = apollo13_make_css_rule( 'border-left-color', $this->theme_options[ 'appearance' ][ 'menu_lvl1_sep_color' ]);
$menu_touch_sep_color   = apollo13_make_css_rule( 'border-top-color', $this->theme_options[ 'appearance' ][ 'menu_lvl1_sep_color' ]);
$menu_lvl2_sep_color    = apollo13_make_css_rule( 'border-top-color', $this->theme_options[ 'appearance' ][ 'menu_lvl2_sep_color' ]);
$menu_lvl1_font_size    = apollo13_make_css_rule( 'font-size', $this->theme_options[ 'appearance' ][ 'menu_lvl1_font_size' ]);
$menu_lvl1_color        = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'menu_lvl1_color' ]);
$menu_lvl1_hover_color  = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'menu_lvl1_hover_color' ]);
$menu_lvl1_active_color = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'menu_lvl1_active_color' ]);
$menu_lvl2_font_size    = apollo13_make_css_rule( 'font-size', $this->theme_options[ 'appearance' ][ 'menu_lvl2_font_size' ]);
$menu_lvl2_color        = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'menu_lvl2_color' ]);
$menu_lvl2_hover_color  = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'menu_lvl2_hover_color' ]);
$menu_lvl2_active_color = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'menu_lvl2_active_color' ]);



/*
 *  footer part
 */
$footer_bg_color        = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'appearance' ][ 'footer_bg_color' ]);
$footer_bg_color_ie     = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'appearance' ][ 'footer_bg_color' ]);
$footer_arrow_color     = apollo13_make_css_rule( 'border-bottom-color', $this->theme_options[ 'appearance' ][ 'footer_bg_color' ]);
//$footer_font_color = apollo13_make_css_rule( 'color', $this->theme_options[ 'appearance' ][ 'footer_font_color' ]);
$footer_font_size       = apollo13_make_css_rule( 'font-size', $this->theme_options[ 'appearance' ][ 'footer_font_size' ]);
$other_albums_bottom    = apollo13_make_css_rule( 'bottom', $this->theme_options[ 'albums' ][ 'album_thumb_height' ]);



/*
 *  blog
 */
$blog_brick_width       = apollo13_make_css_rule( 'width', $this->theme_options[ 'blog' ][ 'brick_width' ]);
$blog_brick_margin_b    = apollo13_make_css_rule( 'margin-bottom', $this->theme_options[ 'blog' ][ 'brick_margin' ]);
$blog_brick_margin_r    = apollo13_make_css_rule( 'margin-right', (((int)$this->theme_options[ 'blog' ][ 'brick_margin' ])/2),'%fpx' );
$blog_brick_margin_l    = apollo13_make_css_rule( 'margin-left', (((int)$this->theme_options[ 'blog' ][ 'brick_margin' ])/2),'%fpx' );
$blog_content_bg        = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'blog' ][ 'blog_content_bg' ]);
$blog_content_bg_ie     = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'blog' ][ 'blog_content_bg' ]);
$archive_content_bg     = apollo13_make_css_rule( 'background-color', $this->theme_options[ 'blog' ][ 'archive_content_bg' ]);
$archive_content_bg_ie  = apollo13_ie_color     ( 'background-color', $this->theme_options[ 'blog' ][ 'archive_content_bg' ]);



/*
 *  albums
 */
$albums_border_size   = apollo13_make_css_rule( 'border-width', $this->theme_options[ 'albums' ][ 'albums_border_size' ]);
$albums_border_color  = apollo13_make_css_rule( 'border-color', $this->theme_options[ 'albums' ][ 'albums_border_color' ]);
$albums_title_size    = apollo13_make_css_rule( 'font-size', $this->theme_options[ 'albums' ][ 'albums_title_size' ]);

$albums_brick_width    = apollo13_make_css_rule( 'width', $this->theme_options[ 'albums' ][ 'albums_brick_width' ]);
$temp = $this->theme_options[ 'albums' ][ 'albums_brick_height' ];
// if 0 then height if fluid
if($temp === '0px' || $temp === '0')
    $albums_brick_height = 'height: auto;';
else
    $albums_brick_height = apollo13_make_css_rule( 'height', $temp);

$albums_brick_margin_b = apollo13_make_css_rule( 'margin-bottom', $this->theme_options[ 'albums' ][ 'albums_brick_margin' ]);
$albums_brick_margin_r = apollo13_make_css_rule( 'margin-right', (((int)$this->theme_options[ 'albums' ][ 'albums_brick_margin' ])/2),'%fpx' );
$albums_brick_margin_l = apollo13_make_css_rule( 'margin-left', (((int)$this->theme_options[ 'albums' ][ 'albums_brick_margin' ])/2),'%fpx' );
$albums_brick_padd_t   = apollo13_make_css_rule( 'padding-top', $this->theme_options[ 'albums' ][ 'albums_brick_margin' ]);
$albums_brick_padd_r   = apollo13_make_css_rule( 'padding-right', (((int)$this->theme_options[ 'albums' ][ 'albums_brick_margin' ])/2),'%fpx' );
$albums_brick_padd_l   = apollo13_make_css_rule( 'padding-left', (((int)$this->theme_options[ 'albums' ][ 'albums_brick_margin' ])/2),'%fpx' );



/*
 *  single album
 */
$album_thumb_height   = apollo13_make_css_rule( 'height', $this->theme_options[ 'albums' ][ 'album_thumb_height' ]);
$album_thumb_width    = apollo13_make_css_rule( 'width', $this->theme_options[ 'albums' ][ 'album_thumb_width' ]);

$album_brick_width    = apollo13_make_css_rule( 'width', $this->theme_options[ 'albums' ][ 'album_brick_width' ]);
$temp = $this->theme_options[ 'albums' ][ 'album_brick_height' ];
// if 0 then height if fluid
if($temp === '0px' || $temp === '0')
    $album_brick_height = 'height: auto;';
else
    $album_brick_height = apollo13_make_css_rule( 'height', $temp);

$album_brick_margin_b = apollo13_make_css_rule( 'margin-bottom', $this->theme_options[ 'albums' ][ 'album_brick_margin' ]);
$album_brick_margin_r = apollo13_make_css_rule( 'margin-right', (((int)$this->theme_options[ 'albums' ][ 'album_brick_margin' ])/2),'%fpx' );
$album_brick_margin_l = apollo13_make_css_rule( 'margin-left', (((int)$this->theme_options[ 'albums' ][ 'album_brick_margin' ])/2),'%fpx' );
$album_brick_padd_t   = apollo13_make_css_rule( 'padding-top', $this->theme_options[ 'albums' ][ 'album_brick_margin' ]);
$album_brick_padd_r   = apollo13_make_css_rule( 'padding-right', (((int)$this->theme_options[ 'albums' ][ 'album_brick_margin' ])/2),'%fpx' );
$album_brick_padd_l   = apollo13_make_css_rule( 'padding-left', (((int)$this->theme_options[ 'albums' ][ 'album_brick_margin' ])/2),'%fpx' );



/*
 *  fonts
 */
$temp               = explode(':', $this->theme_options[ 'fonts' ][ 'normal_fonts' ]);
$normal_fonts       = ($temp[0] === 'default')? '' : apollo13_make_css_rule( 'font-family', $temp[0], '%s, sans-serif' );
$temp               = explode(':', $this->theme_options[ 'fonts' ][ 'titles_fonts' ]);
$titles_fonts       = ($temp[0] === 'default')? '' : apollo13_make_css_rule( 'font-family', $temp[0], '%s, sans-serif' );
$temp               = explode(':', $this->theme_options[ 'fonts' ][ 'nav_menu_fonts' ]);
$nav_menu_font      = ($temp[0] === 'default')? '' : apollo13_make_css_rule( 'font-family', $temp[0], '%s, sans-serif' );


/**********************************
 * START OF CSS
 **********************************/
$user_css = "
/* ==================
   GLOBAL
   ==================*/
html{
	$body_bg_color
	$body_image
	$body_position
	$body_repeat
}
a{
    $links_color
}
a:hover{
    $links_color_hover
}
h1,h2,h3,h4,h5,
h1 a,h2 a,h3 a,h4 a,h5 a,
.post-title a, a.post-title{
    $headings_color
    $titles_fonts
}
h1 a:hover,h2 a:hover,h3 a:hover,h4 a:hover,h5 a:hover,
.post-title a:hover, a.post-title:hover{
    $headings_color_hover
}
.more-link,
input[type=\"submit\"],
.post-icon,
#comments-title:before,
#reply-title:before{
    $buttons_bg_color
}
.lt-ie9 .more-link,
.lt-ie9 input[type=\"submit\"],
.lt-ie9 .post-icon,
.lt-ie9 #comments-title:before,
.lt-ie9 #reply-title:before{
    $buttons_bg_color_ie
}
.more-link:hover,
input[type=\"submit\"]:hover,
a.post-icon:hover{
    $buttons_bg_color_hover
}
.lt-ie9 .more-link:hover,
.lt-ie9 input[type=\"submit\"]:hover,
.lt-ie9 a.post-icon:hover{
    $buttons_bg_color_hover_ie
}


/* ==================
   FONTS
   ==================*/
/* All things font(menu, interactive elements, labels).
 * Not used for content text and titles
 */
body,
.a13-button,
input[type=\"submit\"],
a.more-link,
#header .search input{
	$nav_menu_font
}

/* Text content font */
.real-content,
.widget a.content,
#head-widgets .content .text,
div.textwidget,
div.widget_rss li,
div.twitter_widget p.content,
div.about-author,
div.comments-area,
input[type=\"text\"],
input[type=\"search\"],
input[type=\"password\"],
textarea,
select{
    $normal_fonts
}


/* ==================
   HEADER
   ==================*/
#header,
#access.touch .menu-container{
    $header_bg_color
}
.lt-ie9 #header{
    $header_bg_color_ie
}
.add-ons,
#head-widgets .handle{
    $addons_bg_color
    $addons_font_size
}
.lt-ie9 .add-ons{
    $addons_bg_color_ie
}
.hide-switch{
    $addons_arrow_color
}
#logo a{
	$logo_image
}
#access h3.assistive-text{
    $menu_lvl1_color
    $menu_lvl1_font_size
}
.top-menu ul{
    $menu_bg_color
}
.lt-ie9 .top-menu ul{
    $menu_bg_color_ie
}
.top-menu > li{
    $menu_lvl1_sep_color
}
#access.touch li{
    $menu_touch_sep_color
}
.top-menu li a{
    $menu_lvl1_color
    $menu_lvl1_font_size
}
.top-menu li a:hover{
    $menu_lvl1_hover_color
}
.top-menu li.current-menu-item > a{
    $menu_lvl1_active_color
}
.top-menu li li a{
    $menu_lvl2_sep_color
    $menu_lvl2_color
    $menu_lvl2_font_size
}
.top-menu li li a:hover{
    $menu_lvl2_hover_color
}
.top-menu li li.current-menu-item > a{
    $menu_lvl2_active_color
}


/* ==================
   FOOTER
   ==================*/
#footer,
#thumb-tray .inner,
#other-albums{
    $footer_bg_color
}
#other-albums{
    $other_albums_bottom
}
.lt-ie9 #footer,
.lt-ie9 #thumb-tray .inner,
.lt-ie9 #other-albums{
    $footer_bg_color_ie
}
#tray-button:after{
    $footer_arrow_color
}
#footer, .glass-switch{
     $footer_font_size
}


/* ==================
   ALBUMS LIST
   ==================*/
.albums .active img{
    $albums_border_size
    $albums_border_color
}
.albums .item h2{
    $albums_title_size
}
#thumb-tray{
    $album_thumb_height
}
#thumb-list li{
    $album_thumb_width
}
.bricks-album{
    $album_brick_padd_t
    $album_brick_padd_l
    $album_brick_padd_r
}
.bricks-album .brick{
    $album_brick_margin_b
    $album_brick_margin_r
    $album_brick_margin_l
    $album_brick_height
    $album_brick_width
}
.bricks-album .brick img{
    $album_brick_height
}

#albums-view-bricks{
    $albums_brick_padd_t
    $albums_brick_padd_l
    $albums_brick_padd_r
}
#albums-view-bricks .brick{
    $albums_brick_margin_b
    $albums_brick_margin_r
    $albums_brick_margin_l
    $albums_brick_height
    $albums_brick_width
}
#albums-view-bricks .brick img{
    $albums_brick_height
}


/* ==================
   MASONRY STYLE BLOG
   ==================*/
.brick{
    $blog_brick_width
    $blog_brick_margin_b
    $blog_brick_margin_r
    $blog_brick_margin_l
}
body.blog #content{
    $blog_content_bg
}
.lt-ie9 body.blog #content{
    $blog_content_bg_ie
}
body.archive #content,
body.search #content{
    $archive_content_bg
}
.lt-ie9 body.archive #content,
.lt-ie9 body.search #content{
    $archive_content_bg_ie
}

";

return $user_css;
