<?php
/*
 * For getting URL of current page
 */
if(!function_exists('a13_current_url')){
    function a13_current_url(){
        global $wp;

        //no permalinks
        if($wp->request === NULL){
            $current_url = add_query_arg( $wp->query_string, '', home_url( $wp->request ) );
        }
        else{
            $current_url = trailingslashit(home_url(add_query_arg(array(),$wp->request)));
        }

        return $current_url;
    }
}


/*
 * Date of post
 */
if(!function_exists('a13_posted_on')){
    function a13_posted_on( $date_format = '' ) {
        return sprintf( '<a href="%1$s" rel="bookmark" class="date">%2$s</a>',
            esc_url(get_permalink()), /* link to day archives - get_day_link(get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' )), (http://justintadlock.com/archives/2010/08/06/linking-post-published-dates-to-their-archives)*/
            ( strlen( $date_format ) ? get_the_date( $date_format ) : get_the_date() )
        );
    }
}


/*
 * Date and author
 */
if(!function_exists('a13_date_and_author')){
    function a13_date_and_author( $date_format = '' ) {
        return
            a13_posted_on($date_format).' '
            //author link
            .sprintf( __fe( 'by <a class="author" href="%1$s" title="%2$s">%3$s</a>' ),
                esc_url(get_author_posts_url( get_the_author_meta( 'ID' ) )),
                sprintf( esc_attr( __fe( 'View all posts by %s' ) ), get_the_author() ),
                get_the_author()
            );
    }
}


/*
* Categories that post was posted in
*/
if(!function_exists('a13_posted_in')){
    function a13_posted_in( $separator = '<span>/</span>' ) {
        // Retrieves tag list of current post, separated by commas.
        if ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
            $posted_in = '%1$s';
        } else {
            $posted_in = __fe( 'Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.' );
        }
        // Prints the string, replacing the placeholders.
        printf(
            $posted_in,
            get_the_category_list( $separator ),
            '',//$tag_list,
            esc_url(get_permalink()),
            the_title_attribute( 'echo=0' )
        );
    }
}


/*
* Post info: categories, tags, comments, edit
*/
if(!function_exists('a13_post_info')){
    function a13_post_info() {
        $tags = '';
        $tag_list = get_the_tag_list( __fe('Tags' ).': ', ', ' );
        if ( $tag_list ) {
            $tags = '<span class="tags">'.$tag_list.'</span>';
        }
        ?>
    <div class="post-info">
        <span class="categories"><?php _fe('Category' ); ?>: <?php a13_posted_in( ', ' ); ?></span>
        <?php echo $tags; ?>
        <?php echo ' <span class="comments"><a href="' . esc_url(get_comments_link()) . '" title="' . sprintf(esc_attr(__fe( '%d Comment(s)' )), get_comments_number()) . '">' . sprintf(__fe( '%d Comment(s)' ), get_comments_number()) . '</a></span>'; ?>
        <?php edit_post_link( __fe( 'Edit' ) ); ?>
    </div>
    <?php
    }
}



/*
* Modify password form
*/
if(!function_exists('custom_password_form')){
    function custom_password_form($content) {
        $content = '<div class="password-form">'.$content.'</div>';
        return $content;
    }
}


/*
* Checks if current page has active sidebar
 * returns false if there is no active sidebar,
 * if there is active sidebar it returns its name
*/
if(!function_exists('a13_has_active_sidebar')){
    function a13_has_active_sidebar() {
        if( defined('CONTACT_PAGE') && CONTACT_PAGE ){
            if( is_active_sidebar('contact-widget-area' )){
                return 'contact-widget-area';
            }
        }
        elseif( is_page() ){
            if( is_active_sidebar('pages-widget-area' )){
                return 'pages-widget-area';
            }
        }
        elseif( is_home() || is_archive() || is_search() || is_single() || is_404() ){
            if( is_active_sidebar('blog-widget-area' )){
                return 'blog-widget-area';
            }
        }

        return false;
    }
}


/*
* Get classes for body element
*/
if(!function_exists('a13_get_body_classes')){
    function a13_get_body_classes() {
        global $apollo13, $wp_version;


        //forms validation
        $body_class = ($apollo13->get_option( 'advance', 'apollo_validation' ) == 'on')? VALIDATION_CLASS : '';

        //front page class
        $body_class .= (isset($body_fp_class))? (' '. $body_fp_class) : '';

        //narrow or wide
        $body_class .= ' '.$apollo13->get_option( 'appearance', 'layout_style' );

        //WP version above or equal 3.8
        if(version_compare( $wp_version, '3.8', '>=')){
            $body_class .= ' wp-3_8';
        }

        //full width for masonry
        if( (is_home() && $apollo13->get_option('blog', 'blog_full_width') == 'on' && $apollo13->get_option('blog', 'blog_layout_style') == 'masonry')
            ||
            ((is_archive() || is_search()) && $apollo13->get_option('blog', 'archive_full_width') == 'on'  && $apollo13->get_option('blog', 'archive_layout_style') == 'masonry')
        ){
            $body_class .= ' full-width';
        }

        if(defined('ALBUM_PAGE')){
            //album bricks theme
            if($apollo13->get_meta('_theme') == 'bricks'){
                $body_class .= ' bricks-theme';
            }
            //fully visible album
            elseif($apollo13->get_meta('_fit_album') == '1'){
                $body_class .= ' album-fully-visible';
            }
            //protected album
            if(defined('ALBUM_PAGE_PROTECTED')){
                $body_class .= ' album-protected';
            }

        }


        if(defined('ALBUMS_LIST_PAGE')){
            $body_class .= ' albums-list-page';
        }

        return $body_class;
    }
}


/*
* Get classes for mid element
*/
if(!function_exists('a13_get_mid_classes')){
    function a13_get_mid_classes() {
        global $apollo13;

        //check if there is active sidebar for current page
        $force_full_width = false;
        if(a13_has_active_sidebar() === false){
            $force_full_width = true;
        }

        //mid classes for type of layout align and widget area display(on/off)
        $mid_classes = '';
        if( is_home() ){
            if($force_full_width || $apollo13->get_option('blog', 'blog_sidebar') == 'off'){
                define( 'FULL_WIDTH', true );
                $mid_classes .= ' full-width';
            }
        }
        elseif( is_front_page() ){
            if($force_full_width || get_post_meta(get_option('page_on_front'), '_widget_area', true) == 'off'){
                define( 'FULL_WIDTH', true );
                $mid_classes .= ' full-width';
            }
        }
        elseif( is_archive() || is_search() ){
            if($force_full_width || $apollo13->get_option('blog', 'archive_sidebar') == 'off'){
                define( 'FULL_WIDTH', true );
                $mid_classes .= ' full-width';
            }
        }
        elseif( is_singular() ){
            if($force_full_width || get_post_meta(get_the_ID(), '_widget_area', true) == 'off'){
                define( 'FULL_WIDTH', true );
                $mid_classes .= ' full-width';
            }
        }
        else{
            if($force_full_width){
                $mid_classes .= ' full-width';
            }
        }

        //glass class
        if(!(defined('ALBUM_PAGE'))){
            $mid_classes .= ' glass';
        }

        return $mid_classes;
    }
}


/*
* Prints search form with custom id for each displayed form one one page
*/
if(!function_exists('a13_search_form')){
    function a13_search_form( $form ) {
        static $search_id = 1;
        $field_search = '';
        $helper_search = get_search_query() == '' ? true : false;
        $field_search = '<input' .
            ' placeholder="' . __fe( 'Type And Press Enter' ) . '" ' .
            'type="search" name="s" id="s' . $search_id . '" value="' .
            ( $helper_search ? '' : get_search_query() ) .
            '" />';

        $form = '
                <form class="search-form" role="search" method="get" id="searchform' . $search_id . '" action="' . esc_url(home_url( '/' )) . '" >
                    <fieldset class="semantic">
                        ' . $field_search . '
                        <input type="submit" id="searchsubmit' . $search_id . '" title="'. esc_attr( __fe('Search' ) ) .'" value=" " />
                    </fieldset>
                </form>';

        //next call will have different ID
        $search_id++;
        return $form;
    }
}


/*
 * Function serving theme contact form
 */
if(!function_exists('a13_contact_form')){
    function a13_contact_form( $email_to = '' ){
        static $contact_id = 1;
        static $email_send_already = false;
        static $title_msg      = '';
        static $success        = false;

        $using_captcha  = function_exists( 'cptch_display_captcha_custom' );

        $name_error     = false;
        $email_error    = false;
        $content_error  = false;
        $subject_error  = false;
        $captcha_error  = false;

        $name    = isset($_POST['apollo13-contact-name'])?trim($_POST['apollo13-contact-name']):'';
        $email   = isset($_POST['apollo13-contact-email'])?trim($_POST['apollo13-contact-email']):'';
        $subject = isset($_POST['apollo13-contact-subject'])?trim($_POST['apollo13-contact-subject']):'';
        $content = isset($_POST['apollo13-contact-content'])?trim($_POST['apollo13-contact-content']):'';

        if( isset( $_POST['apollo13-contact-form'] ) ){
            $site = get_bloginfo('name');

            if( empty( $email_to ) || ! is_email( $email_to ) ){
                $email_to = get_option('admin_email');
            }

            if( empty( $name ) )
                $name_error = true;
            if( empty( $email ) || ! is_email( $email ) )
                $email_error = true;
            if( empty( $subject ) )
                $subject_error = true;
            if( empty( $content ) )
                $content_error = true;
            if( $using_captcha && cptch_check_custom_form() !== true )
                $captcha_error = true;

            if( $name_error == false && $email_error == false && $content_error == false && $subject_error == false && $captcha_error == false){
                $mail_subject = $site . __fe( ' - message from contact form' );
                $body = __fe( 'Site' ) . ': ' . $site . "\n\n"
                    . __fe( 'Name' ) . ': ' . $name . "\n\n"
                    . __fe( 'Email' ) . ': ' . $email . "\n\n"
                    . __fe( 'Subject' ) . ': ' . $subject . "\n\n"
                    . __fe( 'Message' ) . ': ' . $content;
                $headers = 'From: ' . " $name <$email>\r\n";
                $headers .= 'Reply-To: ' ." $email\r\n";

                if(!$email_send_already){
                    //to not send multiple emails if there is more then just one contact form on page
                    $email_send_already = true;

                    if( wp_mail( $email_to, $mail_subject, $body, $headers ) ){
                        $title_msg = __fe( 'Success sending form' );
                        $success = true;
                    }
                    else{
                        $title_msg = __fe( 'Something wrong. Try again!' );
                    }
                }
            }
            else{
                $title_msg = __fe( 'Error in form' );
            }
        }

        //if message sent empty text of message(anti spam)
        if($success){
            $content = '';
        }

        //captcha plugin
        $captcha = '';
        if( function_exists( 'cptch_display_captcha_custom' ) ) {
            $cptch_options = get_option( 'cptch_options' );

            $captcha = '<p class="cptch_block'.($captcha_error ? ' error"' : '').'">'
                . ("" != $cptch_options['cptch_label_form'] ? ('<label>'. stripslashes( $cptch_options['cptch_label_form'] ) .'</label>') : '')
                . '<input type="hidden" name="cntctfrm_contact_action" value="true" />'
                . cptch_display_captcha_custom()
                . '</p>';
        }

        //if some submit info than prepare HTML
        $submit_info = empty($title_msg)? '': '<div class="submit-info">' . $title_msg . '</div>';

        $ssss = empty($_SERVER["HTTPS"]) ? '' : ($_SERVER["HTTPS"] == "on") ? "s" : "";

        $html = '
                        <form action="' . a13_current_url() . '" method="post" name="apollo-contact-form" class="contact-form message-form clearfix">
                            ' . $submit_info . '
                            <div class="error-info">' . __fe('Please correct form' ) . '</div>
                            <p' . ($name_error ? ' class="error"' : '') . '>
                                <label class="visuallyhidden" for="apollo13-contact-name'.$contact_id.'">' . __fe( 'Name' ) . ' <span>(' . __fe( 'required' ) . ')</span></label>
                                <input id="apollo13-contact-name'.$contact_id.'" name="apollo13-contact-name" type="text" aria-required="true" placeholder="' . esc_attr(__fe( 'Name' )) . '*" title="' . esc_attr(__fe( 'Name' )) . '*" value="' . esc_attr( $name ) . '" />
                            </p>
                            <p' . ($email_error ? ' class="error"' : '') . '>
                                <label class="visuallyhidden" for="apollo13-contact-email'.$contact_id.'">' . __fe( 'Email' ) . ' <span>(' . __fe( 'required' ) . ')</span></label>
                                <input id="apollo13-contact-email'.$contact_id.'" name="apollo13-contact-email" type="text" aria-required="true" placeholder="' . esc_attr(__fe( 'Email' )) . '*" title="' . esc_attr(__fe( 'Email' )) . '*" value="' . esc_attr( $email ) . '" class="email" />
                            </p>
                            <p' . ($subject_error ? ' class="error"' : '') . '>
                                <label class="visuallyhidden" for="apollo13-contact-subject'.$contact_id.'">' . __fe( 'Subject' ) . ' <span>(' . __fe( 'required' ) . ')</span></label>
                                <input class="placeholder" id="apollo13-contact-subject'.$contact_id.'" aria-required="true" name="apollo13-contact-subject" type="text" placeholder="' . esc_attr(__fe( 'Subject' )) . '*" title="' . esc_attr(__fe( 'Subject' )) . '*" value="' . esc_attr( $subject ) . '" />
                            </p>'
                            .$captcha.
                            '<p class="full' . ($content_error ? ' error' : '') . '">
                                <label class="visuallyhidden" for="apollo13-contact-content'.$contact_id.'">' . __fe( 'Message' ) . ' <span>(' . __fe( 'required' ) . ')</span></label>
                                <textarea id="apollo13-contact-content'.$contact_id.'" name="apollo13-contact-content" rows="10" cols="40" placeholder="' . esc_attr(__fe( 'Message' )) . '*" title="' . esc_attr(__fe( 'Message' )) . '*">' . esc_textarea($content) . '</textarea>
                            </p>
                            <span class="info">' . __fe( 'required' ) . ' *</span>
                            <p class="form-submit">
                                <input type="hidden" name="apollo13-contact-form" value="send" />
                                <input type="submit" value="' . esc_attr(__fe( 'Submit form' )) . '" />
                            </p>
                        </form>';

        $contact_id++;//new id for next form

        return $html;
    }
}


/*
 * Sets the post excerpt length to 30 words.
 */
if(!function_exists('a13_excerpt_length')){
    function a13_excerpt_length( $length ) {
        return 30;
    }
}


/*
* This filter is used by wp_trim_excerpt() function.
* By default it set to echo '[...]' more string at the end of the excerpt.
*/
if(!function_exists('a13_new_excerpt_more')){
    function a13_new_excerpt_more($more) {
        global $post;
        return '<p><a class="more-link" href="'. get_permalink($post->ID) . '">' . __fe('Read more' ) . '</a></p>';
    }
}


/*
* Make excerpt for comments
* used in widgets
*/
if(!function_exists('a13_get_comment_excerpt')){
    function a13_get_comment_excerpt($comment_ID = 0, $num_words = 20) {
        $comment = get_comment( $comment_ID );
        $comment_text = strip_tags($comment->comment_content);
        $blah = explode(' ', $comment_text);
        if (count($blah) > $num_words) {
            $k = $num_words;
            $use_dotdotdot = 1;
        } else {
            $k = count($blah);
            $use_dotdotdot = 0;
        }
        $excerpt = '';
        for ($i=0; $i<$k; $i++) {
            $excerpt .= $blah[$i] . ' ';
        }
        $excerpt .= ($use_dotdotdot) ? '[...]' : '';
        return apply_filters('get_comment_excerpt', $excerpt);
    }
}


/*
* It replaces WP default action while closing children comments block
* Useful to save your nerves
*/
if(!function_exists('a13_comment_end')){
    function a13_comment_end( $comment, $args, $depth ) {
        echo '</div>';
        return;
    }
}


/*
* Changes default comment template
* Closing </div> for this block is produced by comment_end()
* It is strange, I know :-)
*/
if(!function_exists('a13_comment')){
    function a13_comment( $comment, $args, $depth ) {
        $GLOBALS['comment'] = $comment;

        switch ( $comment->comment_type ) :
            case '' :
                ?>
                    <div <?php comment_class( 'comment-block' ); ?> id="comment-<?php comment_ID(); ?>">

                        <div class="comment-inside">
                            <a class="avatar" href="<?php comment_author_url(); ?>" title=""><?php echo get_avatar( $comment, 50 ) ; ?></a>
                            <div class="comment-info">
                                <span class="author"><?php comment_author_link(); ?></span>
                                <?php _fe('on'); ?>
                                <span class="date"><?php
                                    printf( '<a href="%1$s">%2$s</a>',
                                        esc_url( get_comment_link( $comment->comment_ID ) ),
                                        /* translators: 1: date, 2: time */
                                        sprintf( __fe( '%1$s at %2$s' ), get_comment_date(), get_comment_time() )
                                    );
                                    ?></span>
                                <?php
                                comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) );
                                ?>
                            </div>
                            <div class="comment-text">
                                <?php if ( $comment->comment_approved == '0' ) : ?>
                                <p><em class="comment-awaiting-moderation"><?php _fe( 'Your comment is awaiting moderation.' ); ?></em></p>
                                <?php endif; ?>
                                <?php comment_text(); ?>
                            </div>
                            <div class="clear"></div>
                        </div>
                    <?php
                break;
            case 'pingback'  :
            case 'trackback' :
                ?>
            <div <?php comment_class( 'comment-block' ); ?> id="comment-<?php comment_ID(); ?>">
                <div class="comment-inside clearfix">
                    <p><?php _fe( 'Pingback:' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( '(' . __fe( 'Edit' ) . ')', ' ' ); ?></p>
                </div>
                    <?php
                break;
        endswitch;
    }
}


/*
* Function that return featured image or video for post
*/
if(!function_exists('a13_top_image_video')){
    function a13_top_image_video($post_id, $width = 560, $height = 0, $thumb_size = 'apollo-post-thumb'){
        $img_or_vid = get_post_meta($post_id, '_image_or_video_1', true);

        if( empty( $img_or_vid ) || $img_or_vid == 'post_image_1' ){
            $img = a13_make_post_image($post_id, $thumb_size);
            if( !empty( $img ) ){
                if(is_single()):
                ?>
                <div class="item-image post-media">
                    <?php echo $img; ?>
                </div>
                <?php
                else:
                ?>
                <div class="item-image post-media">
                    <a href="<?php the_permalink( $post_id ); ?>"><?php echo $img; ?></a>
                </div>
                <?php
                endif;
            }
        }

        elseif( $img_or_vid == 'post_video_1' ){
            $src = get_post_meta($post_id, '_post_video_1', true);
            if( !empty( $src ) ){
                ?>
                <div class="item-video post-media">
                    <?php
                    if( $height == 0){
                        $height = ceil((9/16) * $width);
                    }

                    $v_code = wp_oembed_get($src, array(
                        'width' => $width,
                        'height' => $height
                        )
                    );

                    //if no code, try theme function
                    if($v_code === false){
                        echo a13_get_movie($src, $width, $height);
                    }
                    else{
                        echo $v_code;
                    }
                    ?>
                </div>
                <?php
            }
        }
        elseif( $img_or_vid == 'post_slides_1' ){
            $id = get_post_meta($post_id, '_post_slides_1', true);
            if($id === 0) return;

            $slides = a13_make_collection($id, true);
            if(!is_array($slides)) return;

            //add script and style for slider
            wp_enqueue_script('flex-slider');
            wp_enqueue_style('flex-slider');
            $html = '';
            foreach($slides as $slide){
                $html .= '<li>';

                if($slide['type'] == 'image'){
                    $html .= '<img src="'.esc_url($slide['image']).'" title="'.esc_attr($slide['title']).'" alt="" />';
                }
                elseif($slide['type'] == 'video'){
                    $html .= '<iframe width="600" height="338" src="'.esc_url($slide['image']).'" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>';
                }

                $html .= '</li>';
            }
            ?>
            <div class="flexslider">
                <ul class="slides">
                    <?php echo $html; ?>
                </ul>
            </div>
            <?php
        }
    }
}


/*
* Nav buttons for blog
*/
if(!function_exists('a13_blog_nav')){
    function a13_blog_nav() {
        //if WP Painate plugin is installed and active
        if(function_exists('wp_paginate')) {
            wp_paginate();
        }
        //theme pagination
        else{
            global $paged, $wp_query;
            //safe copy for operations
            $c_paged = $paged;

            $max_page = $wp_query->max_num_pages;

            if ( $max_page > 1 ) : ?>
                <div id="posts-nav" class="navigation">
                    <?php
                    echo '<span class="nav-previous">';
                    previous_posts_link( __fe( 'Previous' ) );
                    echo '</span>';

                    //if first page
                    if($c_paged === 0){
                        $c_paged = 1;
                    }
                    for($page = 1; $page <= $max_page; $page++){
                        $class = '';
                        if($page == $c_paged){
                            $class = ' class="current"';
                        }
                        echo '<a href="'.esc_url(get_pagenum_link($page)).'" title="'.esc_attr($page).'" '.$class.'>'.$page.'</a>';
                    }

                    echo '<span class="nav-next">';
                    next_posts_link( __fe( 'Next' ) );
                    echo '</span>';
                    ?>
                </div>
            <?php endif;
        }
    }
}


    /*
    * Filter and RSS for blog
    */
if(!function_exists('a13_blog_info_bar')){
    function a13_blog_info_bar() {
        global $apollo13;

        if($apollo13->get_option( 'blog', 'info_bar' ) == 'on'):
        ?>
        <div class="info-bar">
            <div class="inside">
            <?php
                if($apollo13->get_option( 'blog', 'info_bar_blog_title' ) == 'on'){
                    $blog_h1 = get_the_title(get_option('page_for_posts'));
                    if ( !empty( $blog_h1 ) ){
                        echo ( empty( $blog_h1 ) ? '' : '<h1 class="page-title">' . $blog_h1 . '</h1>' );
                    }
                }
            ?>
            <?php
                $rss = ($apollo13->get_option( 'blog', 'info_bar_rss' ) == 'on');
                $filter = ($apollo13->get_option( 'blog', 'info_bar_filter' ) == 'on');
                if($rss || $filter):
            ?>
                <div class="tools">
                    <?php if($filter): ?>
                    <div id="blog-filters">
                        <span class="action" id="filter-activate"><?php _fe('Filter by'); ?></span>
                        <div>
                            <div class="cat-parent">
                                <h3><?php printf( __fe( 'Categories' ), 10); ?></h3>
                                <ul>
                                    <?php
                                    wp_list_categories(array(
                                        'orderby'            => 'count',
                                        'order'              => 'DESC',
                                        'show_count'         => 1,
                                        'number'             => 10,
                                        'title_li'           => ''
                                    ));
                                    ?>
                                </ul>
                            </div>

                            <div class="tag-parent">
                                <h3><?php printf( __fe( 'Tags' ), 10); ?></h3>
                                <ul>
                                    <?php
                                    $tags = get_tags(array(
                                        'orderby'            => 'count',
                                        'order'              => 'DESC',
                                        'number'             => 10,
                                        'title_li'           => ''
                                    ));
                                    foreach ($tags as $tag){
                                        $tag_link = get_tag_link($tag->term_id);
                                        echo '<li><a href="'.esc_url($tag_link).'" title="'.esc_attr(sprintf( '%s Tag', $tag->name)).'" class="'.esc_attr($tag->slug).'">'.$tag->name.'</a> ('.$tag->count.')</li>';
                                    }
                                    ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php endif; /*$filter*/ ?>
                    <?php if($rss): ?>
                    <a href="<?php echo esc_url(get_bloginfo('rss2_url')); ?>" class="rss-link">RSS</a>
                    <?php endif; /*$rss*/ ?>
                </div>
                <?php endif; /*$rss*/ ?>
            </div>
        </div>
        <?php
        endif; /* info_bar */
    }
}


/*
 * Making images
 */
if(!function_exists('a13_make_post_image')){
    function a13_make_post_image( $post_id, $thumb_size){
        if(empty($post_id)){
            $post_id = get_the_ID();
        }
        if ( has_post_thumbnail($post_id) ) {
            return get_the_post_thumbnail($post_id, $thumb_size );
        }

        return false;
    }
}


/*
 * Detection of type of movie
 * returns array(type, video_id)
 */
if(!function_exists('a13_detect_movie')){
    function a13_detect_movie($src){
        //used to check if it is audio file
        $parts = pathinfo($src);
        $ext = isset($parts['extension'])? strtolower($parts['extension']) : false;

        //http://www.youtube.com/watch?v=e8Z0YTWDFXI
        if (preg_match("/(youtube\.com\/watch\?)?v=([a-zA-Z0-9\-_]+)&?/s", $src, $matches)){
            $type = 'youtube';
            $video_id = $matches[2];
        }
        //http://youtu.be/e8Z0YTWDFXI
        elseif (preg_match("/(https?:\/\/youtu\.be\/)([a-zA-Z0-9\-_]+)&?/s", $src, $matches)){
            $type = 'youtube';
            $video_id = $matches[2];
        }
        // regexp $src http://vimeo.com/16998178
        elseif (preg_match("/(vimeo\.com\/)([0-9]+)/s", $src, $matches)){
            $type = 'vimeo';
            $video_id = $matches[2];
        }
        elseif(strlen($ext) && in_array($ext, array('mp3', 'ogg', 'm4a'))){
            $type = 'audio';
            $video_id = $src;
        }
        else{
            $type = 'html5';
            $video_id = $src;
        }

        return array(
            'type' => $type,
            'video_id' => $video_id
        );
    }
}


/*
 * Returns movie thumb(for youtube, vimeo)
 */
if(!function_exists('a13_get_movie_thumb_src')){
    function a13_get_movie_thumb_src( $video_res, $thumb = '' ){
        if(!empty($thumb)){
            return $thumb;
        }

        $type = $video_res['type'];
        $v_id = $video_res['video_id'];

        if ( $type == 'youtube' ){
            return 'http://img.youtube.com/vi/'.$v_id.'/hqdefault.jpg';
        }
        elseif ( $type == 'vimeo' ){
            return TPL_GFX . '/vimeo.jpg';
        }
        elseif ( $type == 'html5' ){
            return TPL_GFX . '/video.jpg';
        }

        return false;
    }
}


/*
 * Returns movie link to insert it in iframe
 */
if(!function_exists('a13_get_movie_link')){
    function a13_get_movie_link( $video_res, $params = array()){
        $type = $video_res['type'];
        $v_id = $video_res['video_id'];

        if ( $type == 'youtube' ){
            return 'http://www.youtube.com/embed/'.$v_id.'?enablejsapi=1&amp;controls=1&amp;fs=1&amp;hd=1&amp;loop=0&amp;rel=0&amp;showinfo=1&amp;showsearch=0&amp;wmode=transparent';
        }
        elseif ( $type == 'vimeo' ){
            return 'http://player.vimeo.com/video/'.$v_id.'?api=1&amp;title=1&amp;loop=0';
        }
        else{
            return TPL_ADV . '/inc/videojs/player.php?src=' . $v_id . '&amp;w=' . $params['width'] . '&amp;h=' . $params['height'];
        }
    }
}


/*
 * Returns movie iframe or link to movie
 */
if(!function_exists('a13_get_movie')){
    function a13_get_movie( $src, $width = 295, $height = 0 ){
        if( $height == 0){
            $height = ceil((9/16) * $width);
        }

        $video_res  = a13_detect_movie($src);
        $type       = $video_res['type'];
        if($type == 'audio'){
            return a13_get_audio_player($video_res['video_id']);
        }
        else{
            $link       = a13_get_movie_link($video_res, array( 'width' => $width, 'height' => $height ));

            return '<iframe id="crazy'.$type . mt_rand() . '" style="height: ' . $height . 'px; width: ' . $width . 'px; border: none;" src="' . esc_url($link) . '" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>';
        }
    }
}

/*
 * Returns audio player HTML
 */
if(!function_exists('a13_get_audio_player')){
    function a13_get_audio_player($src){
        static $player_count = 0;

        //add script for audio
        wp_enqueue_script('apollo13-audio');
        wp_enqueue_style('audio-css');

        $parts = pathinfo($src);
        $ext = isset($parts['extension'])? strtolower($parts['extension']) : false;
        $setMedia = $ext.':"'.$src.'"';

        $html = '
<script type="text/javascript">
//<![CDATA[
jQuery(document).ready(function(){
	jQuery("#jquery_jplayer_'.$player_count.'").jPlayer({
		ready: function (event) {
			jQuery(this).jPlayer("setMedia", {'.$setMedia.'});
		},
		play: function() { // To avoid both jPlayers playing together.
			jQuery(this).jPlayer("pauseOthers");
		},
		swfPath: "'.TPL_JS.'/audio/",
		supplied: "'.$ext.'",
		wmode: "window",
		cssSelectorAncestor: "#jp_container_'.$player_count.'"
	});
});
//]]>
</script>


		<div id="jp_container_'.$player_count.'" class="jp-audio">
            <div id="jquery_jplayer_'.$player_count.'" class="jp-jplayer"></div>
			<div class="jp-type-single">
				<div class="jp-gui jp-interface">
					<ul class="jp-controls">
						<li><a href="javascript:;" class="jp-play" tabindex="1">play</a></li>
						<li><a href="javascript:;" class="jp-pause" tabindex="1">pause</a></li>
						<li><a href="javascript:;" class="jp-stop" tabindex="1">stop</a></li>
						<li><a href="javascript:;" class="jp-mute" tabindex="1" title="mute">mute</a></li>
						<li><a href="javascript:;" class="jp-unmute" tabindex="1" title="unmute">unmute</a></li>
						<li><a href="javascript:;" class="jp-volume-max" tabindex="1" title="max volume">max volume</a></li>
					</ul>
					<div class="jp-progress">
						<div class="jp-seek-bar">
							<div class="jp-play-bar"></div>

						</div>
					</div>
					<div class="jp-volume-bar">
						<div class="jp-volume-bar-value"></div>
					</div>
					<div class="jp-current-time"></div>
					<div class="jp-duration"></div>
					<ul class="jp-toggles">
						<li><a href="javascript:;" class="jp-repeat" tabindex="1" title="repeat">repeat</a></li>
						<li><a href="javascript:;" class="jp-repeat-off" tabindex="1" title="repeat off">repeat off</a></li>
					</ul>
				</div>
				<div class="jp-no-solution">
					<span>Update Required</span>
					To play the media you will need to either update your browser to a recent version or update your <a href="http://get.adobe.com/flashplayer/" target="_blank">Flash plugin</a>.
				</div>
			</div>
		</div>';

        $player_count++;

        return $html;
    }
}

/**
 * ADDING THUMBNAIL TO RSS
 */
if(!function_exists('a13_rss_post_thumbnail')){
    function a13_rss_post_thumbnail($content) {
        global $post;
        if(has_post_thumbnail($post->ID)) {
            $content = '<p>' . get_the_post_thumbnail($post->ID, 'medium') .
                '</p>' . get_the_excerpt();
        }
        else
            $content = get_the_excerpt();

        return $content;
    }
}

/**
 * FILTER HOOKS
 */
add_filter( 'get_search_form','a13_search_form' );
add_filter( 'excerpt_length', 'a13_excerpt_length' );
add_filter( 'excerpt_more', 'a13_new_excerpt_more' );
add_filter( 'the_password_form', 'custom_password_form');
add_filter( 'the_excerpt_rss', 'a13_rss_post_thumbnail');
add_filter( 'the_content_feed', 'a13_rss_post_thumbnail');
